import time

import pyautogui
from selenium.webdriver.support.select import Select
from selenium.webdriver.support.wait import WebDriverWait

from Util.Util import DriverUtils
import logging


# from common.utils import DriverTools


class BasePage:
    def __init__(self):
        self.driver = DriverUtils.get_web_driver()
        self.set_logger()

    # 查找元素
    def find_el(self, loc, time=10, fre=0.5):
        ele = WebDriverWait(self.driver, time, fre).until(lambda x: x.find_element(*loc))
        return ele

    # 输入文本内容
    def input_text(self, loc, value):
        # 定义该元素对于的文本
        ele = self.find_el(loc)
        # 先清空
        ele.clear()
        # 再输入
        ele.send_keys(value)

    # 滚动条
    def scroll(self, x, y):
        # 横着滚动调整x值，竖着滚动调整y值
        js = "window,scroll({},{})".format(x, y)
        self.driver.execute_script(js)

    # 下拉框选择
    def select_text(self, loc, text):
        # 定位该下拉框对应的元素
        ele = self.find_el(loc)
        # 实例化Select对象
        sle = Select(ele)
        # 调用select选择方法
        sle.select_by_visible_text(text)

    # 选择文件
    def select_document(self,path_str=None):
        time.sleep(1)
        pyautogui.write(path_str)
        time.sleep(1)
        pyautogui.press('enter')
        time.sleep(2)

    # 设置日志记录器
    def set_logger(self):
        logging.basicConfig(level=logging.INFO)
        self.logger = logging.getLogger(__name__)
        # 创建一个处理程序，用于输出到控制台
        console_handler = logging.StreamHandler()
        console_handler.setLevel(logging.INFO)
        # 创建一个处理程序，用于输出到文件
        file_handler = logging.FileHandler('business_knowledge.log')
        file_handler.setLevel(logging.INFO)
        # 创建一个格式化器，用于设置日志格式
        formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
        # 将格式化器添加到处理程序
        console_handler.setFormatter(formatter)
        file_handler.setFormatter(formatter)
        # 将处理程序添加到记录器
        self.logger.addHandler(console_handler)
        self.logger.addHandler(file_handler)


