import logging
import time

import pytest
from selenium import webdriver
from selenium.webdriver import ActionChains
from selenium.webdriver.common.by import By

from BasePage.BasePage import BasePage
from Pages.login_page import LoginPage
from Util.Util import DriverUtils


"""
企业知识库--页面操作
"""


class BusinessKnowledgePage(BasePage):

    def __init__(self):
        super().__init__()
        self.upload_document_helper = UploadDocumentHelper()
        self.ai_editing = (By.XPATH, '//*[@id="App"]/div/header/div[2]/div[2]')  # AI编辑工作室按钮
        self.business_knowledge = (By.XPATH, '//*[@id="App"]/div/div/div[2]/ul/li[3]/div/div/span')  # 企业知识库按钮
        self.quit = (By.XPATH, '//*[@id="App"]/div/section/div[1]/div[1]/div[1]/button/span')  # 返回

        self.folders = (By.XPATH, '//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[1]/div[2]')  # 文件夹列表
        self.newFolder = (By.XPATH, '//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[1]/button[2]/span')  # 新建文件夹
        self.folderName = (By.XPATH, '//*[@id="folderName"]')  # 输入文件夹名
        self.ensure = (By.XPATH, '/html/body/div[3]/div/div[2]/div/div[2]/div[3]/button[2]/span')  # 确定按钮
        self.more = (By.XPATH, '//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[1]/div[2]/div[3]/i')  # 更多
        self.updateFolderName = (By.XPATH, '/html/body/div[3]/div/div/ul/li[1]/span/div')  # 修改名称
        self.deleteFolder = (By.XPATH, '/html/body/div[3]/div/div/ul/li[2]/span/div')  # 删除
        self.ensureDelete = (By.XPATH, '/html/body/div[4]/div/div[2]/div/div[2]/div[3]/button[2]/span')  # 确认

        self.searchInputText = (
            By.XPATH, '//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[1]/div[1]/span/input')  # 搜索文本框
        self.subscriptionWebsiteButton = (
            By.XPATH, '//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[1]/button[1]')  # 订阅网站
        self.updateWebsiteFrequencySelect = (
            By.XPATH, '/html/body/div[3]/div/div[2]/div/div[2]/div[2]/div/form/div[2]/div/div[2]/div/div/div')  # 更新网站频率
        self.updateWebsiteFrequencyDataDiv = (By.XPATH, '/html/body/div[4]/div/div/div/div[2]/div[1]/div/div')  # 更新频率数据

        # 订阅网站列表
        self.subscriptionWebsiteListDiv = (By.XPATH, '//*[@id="website"]/div/div[2]/div[1]')
        # 确定订阅
        self.ensureSubscriptionWebsite = (By.XPATH, '/html/body/div[3]/div/div[2]/div/div[2]/div[3]/div/button[2]/span')
        # 清空
        self.clearButton = (By.XPATH, '//*[@id="website"]/div/div[1]/span[2]/span[2]')
        # 去除
        self.removeButton = (By.XPATH, '//*[@id="website"]/div/div[2]/div[2]/div[1]/div/div[1]/div[2]')

    """
    通用
    """

    # 进入AI编辑工作室
    def entranceAi(self):
        self.find_el(self.ai_editing).click()

    # 进入企业知识库
    def entranceBusinessKnowledge(self):
        self.find_el(self.business_knowledge).click()

    # 返回/首页 退出
    def quitBusinessKnowledge(self):
        self.find_el(self.quit).click()

    """
    文件夹管理
    """

    # 新建文件夹操作 输入长度测试点
    def newFolderControl(self, folderNameInput=None):
        self.find_el(self.newFolder).click()  # 弹出输入框
        self.input_text(self.folderName, folderNameInput)  # 输入文件夹名称
        self.find_el(self.ensure).click()  # 点击确认

    # 删除文件夹
    def deleteFolderControl(self):
        self.find_el(self.more).click()  # 点击更多
        time.sleep(1)
        self.find_el(self.deleteFolder).click()  # 弹出二次删除弹框
        time.sleep(1)
        self.find_el(self.ensureDelete).click()  # 点击确认删除

    # 修改文件夹
    def updateFolderControl(self, updateFolderName=None):
        self.find_el(self.more).click()  # 点击更多
        time.sleep(1)
        self.find_el(self.updateFolderName).click()  # 弹出修改弹框
        self.input_text(self.folderName, updateFolderName)
        time.sleep(1)
        self.find_el(self.ensureDelete).click()  # 点击确认

    # 遍历点击文件夹
    def traverseFolder(self):
        elementSpans = self.find_el(self.folders).find_elements('tag name', 'span')
        for elementSpan in elementSpans:
            elementSpan.click()
            time.sleep(2)

    """
    搜索文档
    """

    # 搜索
    def searchDocument(self, keyName=None):
        self.input_text(self.searchInputText, keyName)
        time.sleep(2)

    """
    网站订阅
    """

    # 点击订阅网站 弹出弹框
    def subscriptionWebsiteStart(self):
        self.find_el(self.subscriptionWebsiteButton).click()

    # 订阅频率选中-根据optionName进行选中
    def subscriptionWebsiteFrequencySelect(self, optionName=None):
        self.find_el(self.updateWebsiteFrequencySelect).click()  # 点击更新频率
        time.sleep(2)
        # 获取到全部数据
        elementsFrequencyOptions = self.find_el(self.updateWebsiteFrequencyDataDiv).find_elements(By.XPATH, '/html/body/div[4]/div/div/div/div[2]/div[1]/div/div/div[contains(@class, "ant-select-item")]')
        # 订阅频率选择
        for elementsFrequencyOption in elementsFrequencyOptions:
            # 模拟鼠标悬停到选项上
            ActionChains(driver).move_to_element(elementsFrequencyOption).perform()
            time.sleep(1)
            # 模拟点击选项
            if optionName == elementsFrequencyOption.text:
                logging.info("-----选择的更新频率:%s-----", elementsFrequencyOption.text)
                elementsFrequencyOption.click()
                break

    # 选中订阅的网站
    def subscriptionWebsiteSelect(self, optionsName=None):
        print(optionsName)
        subscriptionWebsiteOptions = self.find_el(self.subscriptionWebsiteListDiv).find_elements(By.XPATH,'//*[@id="website"]/div/div[2]/div[1]/div[contains(@class,"website-item")]')
        subscriptionWebsiteOptionTexts = self.find_el(self.subscriptionWebsiteListDiv).find_elements(By.XPATH,'//*[@id="website"]/div/div[2]/div[1]/div/label/span[2]/div/div/div')
        time.sleep(1)
        for subscriptionWebsiteOption,subscriptionWebsiteOptionText in zip(subscriptionWebsiteOptions,subscriptionWebsiteOptionTexts):
            for optionName in optionsName:
                if optionName == subscriptionWebsiteOptionText.text:
                    logging.info("-----选择的网站:%s-----",subscriptionWebsiteOptionText.text)
                    subscriptionWebsiteOption.click()  # 选中

    # 清空网站订阅内容
    def clearSubscriptionWebsite(self):
        self.find_el(self.clearButton).click()

    # 移除订阅的网站
    def removeSubscriptionWebsite(self,count=None):
        for i in range(count):
            self.find_el(self.removeButton).click()

    # 确定订阅网站
    def ensureSubscriptionWebsite(self):
        self.find_el(self.ensureSubscriptionWebsite).click()

    # 网站订阅-整个流程
    def subscriptionWebsite(self):
        self.find_el(self.subscriptionWebsiteButton).click()  # 点击订阅网站 弹出弹框
        time.sleep(2)
        self.find_el(self.updateWebsiteFrequencySelect).click()  # 点击更新频率
        time.sleep(2)
        # 获取到全部数据
        elementsFrequencyOptions = self.find_el(self.updateWebsiteFrequencyDataDiv).find_elements(By.XPATH,
                                                                                                  '/html/body/div[4]/div/div/div/div[2]/div[1]/div/div/div[contains(@class, "ant-select-item")]')
        count = 0
        # 订阅频率选择
        for elementsFrequencyOption in elementsFrequencyOptions:
            # time.sleep(1)
            # self.find_el(self.updateWebsiteFrequencySelect).click()  # 点击更新频率
            # time.sleep(1)
            # 模拟鼠标悬停到选项上
            ActionChains(driver).move_to_element(elementsFrequencyOption).perform()
            time.sleep(1)
            count = count + 1
            # 模拟点击选项
            if (count == len(elementsFrequencyOptions)):
                elementsFrequencyOption.click()
        # 选择订阅的网站
        subscriptionWebsiteOptions = self.find_el(self.subscriptionWebsiteListDiv).find_elements(By.XPATH,
                                                                                                 '//*[@id="website"]/div/div[2]/div[1]/div[contains(@class,"website-item")]')
        for subscriptionWebsiteOption in subscriptionWebsiteOptions:
            subscriptionWebsiteOption.click()  # 选中

        # 确定订阅
        self.find_el(self.ensureSubscriptionWebsite).click()

    """
    上传文档-三种方式
    """
class UploadDocumentHelper(BasePage):
    def __init__(self):
        super().__init__()
        self.uploadDocumentButton = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[2]/div/div[2]/div[2]/div[1]')  # 上传文档按钮
        self.pasteTextButton = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[2]/div/div[2]/div[2]/div[2]')  # 粘贴文本
        self.importWebsiteButton = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[2]/div/div[2]/div[2]/div[3]')  # 导入网站

        self.clickUploadButton = (By.XPATH,'/html/body/div[3]/div/div[2]/div/div[2]/div[2]/div/div[2]/div[2]/div[1]/div')  # 点击上传

    """
    方式一：上传文档
    """
    def uploadDocumentControl(self,str_path):

        time.sleep(1)
        # for str_path in str_paths:
        #     time.sleep(1)
        #     self.find_el(self.uploadDocumentButton).click()  # 点击 弹出弹窗
        #     logging.info(str_path)
        #     time.sleep(1)
        #     self.find_el(self.clickUploadButton).click()  # 弹窗，选择文件
        #     self.select_document(str_path)
        #     time.sleep(1)

        time.sleep(1)
        self.find_el(self.uploadDocumentButton).click()  # 点击 弹出弹窗
        logging.info(str_path)
        time.sleep(1)
        self.find_el(self.clickUploadButton).click()  # 弹窗，选择文件
        self.select_document(str_path)
        time.sleep(1)


    """
    粘贴文本
    """

    """
    导入网站
    """

    """
    文档列表操作
    """

    """
    文档对话
    """

    """
    文件夹对话
    """


if __name__ == '__main__':
    driver = DriverUtils.get_web_driver()
    driver.get('https://rays7.raysgo.com/login')
    time.sleep(1)
    LoginPage().login_username("17373027967", "3149390154Li")
    time.sleep(1)
    businessKnowledge = BusinessKnowledgePage()
    businessKnowledge.entranceAi()
    time.sleep(1)
    businessKnowledge.entranceBusinessKnowledge()
    time.sleep(1)


    stry_paths = []
    for i in range(15):
        stry_paths.append('D:/Word/WORD'+str(i+1)+".docx")

        
    businessKnowledge.upload_document_helper.uploadDocumentControl('D:/Word/WORD1.docx')
    time.sleep(4)
    # businessKnowledge.subscriptionWebsiteStart()
    # time.sleep(1)
    # businessKnowledge.subscriptionWebsiteFrequencySelect("三天更新一次")
    # time.sleep(1)
    # businessKnowledge.subscriptionWebsiteSelect(['出版商务周报官网','中国出版'])
    # time.sleep(2)

    # businessKnowledge.newFolderControl("文件夹名称188")
    # time.sleep(2)
    # while 1:
    #     businessKnowledge.deleteFolderControl()
    # time.sleep(2)
    # # # businessKnowledge.updateFolderControl()
    # # businessKnowledge.traverseFolder()
    # # businessKnowledge.searchDocument("1")
    # businessKnowledge.subscriptionWebsite()
    # time.sleep(2)
